<?php
/*
	Registers settings, adds a new submenu in the admin panel and adds options to array
	@since 0.1

	PixoPoint Menu Animations
	Copyright (c) 2009 PixoPoint Web Development

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as
	published by the Free Software Foundation.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

*/


/**
 * Do not continue processing since file was called directly
 * @since 0.1
 */
if( !defined( 'ABSPATH' ) )
	return;


/**
 * Adds admin menu, stores array and registers settings
 * @since 0.1
 */
add_action( 'admin_menu', 'show_pixopoint_menu_animations_options' );
function show_pixopoint_menu_animations_options() {

	// Add various options for admin page
	$page = add_options_page(
		'PixoPoint Menu: Animations Module Options',
		'PixoPoint Menu Animations',
		'administrator',
		'pixopoint_menuanimations_options',
		'pixopoint_menu_animations_options'
	);
	add_action( "admin_print_scripts-$page", 'pixopoint_superfish_adminhead' );	// Adds various default options into an array
	$pixopoint_setmenuoptions = array(
		'pixopoint_menu_animations_type'                   => 'Basic',
		'pixopoint_menu_basic_speed'                       => 'normal',
		'pixopoint_menu_basic_slidedown'                   => 'on',
		'pixopoint_menu_superfish_sensitivity'             => 'high',
		'pixopoint_menu_superfish_arrows'                  => 'on',
		'pixopoint_menu_superfish_speed'                   => 'normal',
		'pixopoint_menu_superfish_delaymouseover'          => '800',
		'pixopoint_menu_delay'                             => '100',
	);
	// Add default options to an option in the database if it doesn't already exists
	add_option( 'pixopoint_menuanimationsoptions', $pixopoint_setmenuoptions );

	// Register Settings
	register_setting( 'pixopoint-menu', 'pixopoint_menuanimationsoptions', 'pixopoint_menuanimationsvalidate' );
}


/**
 * Whitelist the options for options.php's checks (thanks to Ryan McCue for this tip)
 * @since 0.1
 */
function pixopoint_superfish_whitelist($whitelist) {
	$whitelist['pixopoint_superfish_whitelist'] = array(
		'pixopoint_menuanimationsoptions',
	);
	return $whitelist;
}
add_filter( 'whitelist_options', 'pixopoint_superfish_whitelist' );


/**
 * Sanitize and validate input. Accepts an array, return a sanitized array.
 * @since 0.1
 */
function pixopoint_menuanimationsvalidate($input) {
	// Checking for specific values
	switch ( $input['pixopoint_menu_animations_type'] ) {
		case 'None': break;
		case 'Basic': break;
		case 'Superfish': break;
		case '': break;
		default: die;
	}
	switch ( $input[''] ) {
		case 'None': break;
		case 'Basic': break;
		case 'Superfish': break;
		case '': break;
		default: die;
	}
	switch ( $input['pixopoint_menu_basic_speed'] ){
		case 'slow': break;
		case 'normal': break;
		case 'fast': break;
		case 'instant': break;
		case '': break;
		default: die;
	}
	switch ( $input['pixopoint_menu_superfish_speed'] ){
		case 'slow': break;
		case 'normal': break;
		case 'fast': break;
		case 'instant': break;
		case '': break;
		default: die;
	}
	switch ( $input['pixopoint_menu_superfish_sensitivity'] ) {
		case 'high': break;
		case 'average': break;
		case 'low': break;
		case '': break;
		default: die;
	}
	// Checking for on off values
	switch ( $input['pixopoint_menu_basic_slidedown'] ) {
		case 'on': break;
		case 'off': break;
		case '': break;
		default: die;
	}
	switch ( $input['pixopoint_menu_superfish_arrows'] ) {
		case 'on': break;
		case 'off': break;
		case '': break;
		default: die;
	}
	// Checkin' if they're numeric
	if ( !is_numeric( $input['pixopoint_menu_superfish_delaymouseover'] ) )
		$input['pixopoint_menu_superfish_delaymouseover'] = '0';
	if ( !is_numeric( $input['pixopoint_menu_delay'] ) )
		$input['pixopoint_menu_delay'] = '0';
	// Run through each entry and strip all HTML
	foreach ( $input as $set => $value ) {
		$input[$set] =  wp_filter_nohtml_kses( $input[$set] );
	}
	return $input;
}


/**
 * Stuff for between the head tags
 * @since 0.1
 */
function pixopoint_superfish_adminhead() { ?>
<style type="text/css">
	#icon-pixopoint-menu {
		background:url('<?php echo PIXOPOINT_MENU_ANIMATIONS_URL; ?>screen-icon.png') no-repeat;
	}
</style>
<?php }


function pixopoint_menu_animations_options() {
	$pixopoint_menuanimationsoptions = get_option( 'pixopoint_menuanimationsoptions' );

?>
<div class="wrap">
	<form method="post" action="options.php" id="options">
		<?php wp_nonce_field( 'update-options' ); ?>
		<?php settings_fields( 'pixopoint-menu' ); ?>
		<?php screen_icon('pixopoint-menu'); ?>
		<h2>PixoPoint Menu Animations</h2>

		<p>
			<?php _e( 'The PixoPoint Menu Animations consists of two types of dropdown menu animations. The animations should appear on any menu which uses a class of .sf-menu.', 'pixopoint_menu_animations_lang' ); ?>
			<br /><br /><br />
		</p>

		<h3 class="yup">
			<?php _e( 'No animations', 'pixopoint_menu_animations_lang' ); ?>
			&nbsp;
			<input <?php
				if ( $pixopoint_menuanimationsoptions[pixopoint_menu_animations_type] == 'None' ) { echo 'checked="yes" ';}
			?>type="radio" name="pixopoint_menuanimationsoptions[pixopoint_menu_animations_type]" value="None" />
			<br /><br />
		</h3>
		<h3 class="yup">
			<?php _e( 'Use Basic animations', 'pixopoint_menu_animations_lang' ); ?>
			&nbsp;
			<input <?php
				if ( $pixopoint_menuanimationsoptions[pixopoint_menu_animations_type] == 'Basic' ) { echo 'checked="yes" ';}
			?>type="radio" name="pixopoint_menuanimationsoptions[pixopoint_menu_animations_type]" value="Basic" />
		</h3>
		<table class="widefat" cellspacing="0" id="active-plugins-table">
			<thead>
				<tr>
					<th scope="col" colspan="2"><?php _e( 'Setting', 'pixopoint_menu_animations_lang' ); ?></th>
					<th scope="col"><?php _e( 'Description', 'pixopoint_menu_animations_lang' ); ?></th>
				</tr>
			</thead>
			<tfoot>
				<tr>
					<th scope="col" colspan="3"><?php _e( 'This option does not provide as many features as the Advanced animations option, but does not load as much code and hence your web pages should load marginally quicker when using it.', 'pixopoint_menu_animations_lang' ); ?></th>
				</tr>
			</tfoot>
			<tbody class="plugins">
				<tr class='active'>
					<th scope='row' class='check-column'>

						<select name="pixopoint_menuanimationsoptions[pixopoint_menu_basic_speed]">
						<?php
							switch ( $pixopoint_menuanimationsoptions['pixopoint_menu_basic_speed'] ){
								case 'slow': echo '<option>slow</option><option>normal</option><option>fast</option>'; break;
								case 'normal': echo '<option>normal</option><option>slow</option><option>fast</option>'; break;
								case 'fast': echo '<option>fast</option><option>slow</option><option>normal</option>'; break;
								case 'instant': echo '<option>fast</option><option>normal</option><option>slow</option>'; break; // Note: Instant was removed but is kept for backwards compatibility
								case '': echo '<option>normal</option><option>slow</option><option>fast</option>'; break;
							}
						?>
						</select>
					</th>
					<td class='name'><?php _e( 'Speed of animation', 'pixopoint_menu_animations_lang' ); ?></td>
					<td class='desc'>
						<p><?php _e( 'This option allows you to control the speed of the animated effect.', 'pixopoint_menu_animations_lang' ); ?></p>
					</td>
				</tr>
				<tr class='active'>
					<th scope='row' class='check-column'>
					<?php
						if ( $pixopoint_menuanimationsoptions['pixopoint_menu_basic_slidedown'] == 'on' ) { ?>
							<input type="checkbox" name="pixopoint_menuanimationsoptions[pixopoint_menu_basic_slidedown]" checked="yes" />
						<?php }
						else { ?>
							<input type="checkbox" name="pixopoint_menuanimationsoptions[pixopoint_menu_basic_slidedown]" />
						<?php }
						?>
					</th>
					<td class='name'><?php _e( 'Slide down?', 'pixopoint_menu_animations_lang' ); ?></td>
					<td class='desc'>
						<p><?php _e( 'When activated, this will cause the menus to slide directly downwards instead of appearing from the side.', 'pixopoint_menu_animations_lang' ); ?></p>
					</td>
				</tr>
			</tbody>
		</table>

		<br /><br />

		<h3 class="yup">
			<?php _e( 'Use Advanced Animations', 'pixopoint_menu_animations_lang' ); ?>
			&nbsp;
			<input <?php
				if ( $pixopoint_menuanimationsoptions[pixopoint_menu_animations_type] == 'Superfish' ) { echo 'checked="yes" ';}
			?>type="radio" name="pixopoint_menuanimationsoptions[pixopoint_menu_animations_type]" value="Superfish" />
		</h3>
		<table class="widefat" cellspacing="0" id="active-plugins-table">
			<thead>
				<tr>
					<th scope="col" colspan="2"><?php _e( 'Setting', 'pixopoint_menu_animations_lang' ); ?></th>
					<th scope="col"><?php _e( 'Description', 'pixopoint_menu_animations_lang' ); ?></th>
				</tr>
			</thead>
			<tfoot>
				<tr>
					<th scope="col" colspan="3"><?php _e( 'This option controls how quickly the menus fade into view.', 'pixopoint_menu_animations_lang' ); ?></th>
				</tr>
			</tfoot>
			<tbody class="plugins">
				<tr class='active'>
					<th scope='row' class='check-column'>
						<select name="pixopoint_menuanimationsoptions[pixopoint_menu_superfish_speed]">
						<?php
							switch ( $pixopoint_menuanimationsoptions['pixopoint_menu_superfish_speed'] ){
								case 'slow': echo '<option>slow</option><option>normal</option><option>fast</option><option>instant</option>'; break;
								case 'normal': echo '<option>normal</option><option>slow</option><option>fast</option><option>instant</option>'; break;
								case 'fast': echo '<option>fast</option><option>slow</option><option>normal</option><option>instant</option>'; break;
								case 'instant': echo '<option>instant</option><option>normal</option><option>slow</option><option>fast</option>'; break;
								case '': echo '<option>instant</option><option>normal</option><option>slow</option><option>fast</option>'; break;
							}
						?>
						</select>
					</th>
					<td class='name'><?php _e( 'Speed of fade-in effect', 'pixopoint_menu_animations_lang' ); ?></td>
					<td class='desc'>
						<p><?php _e( 'This option enhances the behaviour of the dropdown by creating an animated fade-in effect.', 'pixopoint_menu_animations_lang' ); ?></p>
					</td>
				</tr>
				<tr class='active'>
					<th scope='row' class='check-column'>
						<input style="width:60px" name="pixopoint_menuanimationsoptions[pixopoint_menu_superfish_delaymouseover]" type="text" value="<?php echo $pixopoint_menuanimationsoptions['pixopoint_menu_superfish_delaymouseover']; ?>" />
					</th>
					<td class='name'><?php _e( 'Mouseover delay (milliseconds)', 'pixopoint_menu_animations_lang' ); ?></td>
					<td class='desc'>
						<p><?php _e( 'This option adds a delay time before the dropdown appears.', 'pixopoint_menu_animations_lang' ); ?></p>
					</td>
				</tr>
				<tr class='active'>
					<th scope='row' class='check-column'>
						<input style="width:60px" name="pixopoint_menuanimationsoptions[pixopoint_menu_delay]" type="text" value="<?php echo $pixopoint_menuanimationsoptions['pixopoint_menu_delay']; ?>" />
					</th>
					<td class='name'><?php _e( 'Hide delay time (milliseconds)', 'pixopoint_menu_animations_lang' ); ?></td>
					<td class='desc'>
						<p><?php _e( 'This option adds a delay before the dropdown disappears. This option is particularly suitable for small menus where users may accidentally hover off of the menu.', 'pixopoint_menu_animations_lang' ); ?></p>
					</td>
				</tr>
				<tr class='active'>
					<th scope='row' class='check-column'>
						<select name="pixopoint_menuanimationsoptions[pixopoint_menu_superfish_sensitivity]">
						<?php
							switch ( $pixopoint_menuanimationsoptions['pixopoint_menu_superfish_sensitivity'] ) {
								case 'high': echo '<option>high</option><option>average</option><option>low</option>'; break;
								case 'average': echo '<option>average</option><option>high</option><option>low</option>'; break;
								case 'low': echo '<option>low</option><option>high</option><option>average</option>'; break;
								case '': echo '<option>high</option><option>average</option><option>low</option>'; break;
							}
						?>
						</select>
					</th>
					<td class='name'><?php _e( 'Sensitivity', 'pixopoint_menu_animations_lang' ); ?></td>
					<td class='desc'>
						<p><?php _e( 'When this option is enabled, the menu will attempt to determine the user\'s intent. On low sensitivity, instead of immediately displaying the dropdown/flyout menu on mouseover, the menu will wait until the user\'s mouse slows down before displaying it.', 'pixopoint_menu_animations_lang' ); ?></p>
					</td>
				</tr>
				<tr class='active'>
					<th scope='row' class='check-column'>
					<?php
						if ( $pixopoint_menuanimationsoptions['pixopoint_menu_superfish_arrows'] == 'on' ) { ?>
							<input type="checkbox" name="pixopoint_menuanimationsoptions[pixopoint_menu_superfish_arrows]" checked="yes" />
						<?php }
						else { ?>
							<input type="checkbox" name="pixopoint_menuanimationsoptions[pixopoint_menu_superfish_arrows]" />
						<?php }
						?>
					</th>
					<td class='name'><?php _e( 'Enable arrow mark-up?', 'pixopoint_menu_animations_lang' ); ?></td>
					<td class='desc'>
						<p><?php _e( 'This option adds a small arrow to any menu option which contains children.', 'pixopoint_menu_animations_lang' ); ?></p>
					</td>
				</tr>
			</tbody>
		</table>

		<input type="hidden" name="action" value="update" />
		<div style="clear:both;padding-top:20px;"></div>
		<p class="submit"><input type="submit" name="Submit" value="<?php _e( 'Update Options' ) ?>" /></p>

		<div style="clear:both;padding-top:20px;"></div>
		<input type="hidden" name="option_page" value="pixopoint_superfish_whitelist" />
		<?php wp_nonce_field( 'pixopoint_superfish_whitelist-options' ); ?>
	</form>
</div>





<?php
}
?>
